@@ -2,7 +2,7 @@
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-# http://www.apache.org/licenses/LICENSE-2.0
+# https://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
@@ -11,11 +11,14 @@
 # limitations under the License.
 
 from twine import __main__ as dunder_main
+from twine import exceptions
 
 import pretend
 
 
 def test_exception_handling(monkeypatch):
-    replaced_dispatch = pretend.raiser(KeyError('foo'))
+    replaced_dispatch = pretend.raiser(
+        exceptions.InvalidConfiguration('foo')
+    )
     monkeypatch.setattr(dunder_main, 'dispatch', replaced_dispatch)
-    assert dunder_main.main() == 'KeyError: foo'
+    assert dunder_main.main() == 'InvalidConfiguration: foo'
